# dockery

Graphical interface for Docker in your console

| ![capture1](https://github.com/marianocarrazana/dockery/assets/17238076/a97f7854-2961-4cab-8596-0f3e3d48224c) | ![capture2](https://github.com/marianocarrazana/dockery/assets/17238076/c656e616-387b-456d-a921-0d836ebaabc4) |
|-|-|

## Installation

### From source

```shell
git clone git@github.com:marianocarrazana/dockery.git
cd dockery
pip install -e .
# update only:
git pull
```

### From pip

```shell
pip install dockery
```

## Usage

Run on your console:

```shell
dockery
```

## Extra commands

```shell
dockery df
dockery ps
dockery volumes
dockery images
dockery stats
```

## **Enjoy it!**
